aboutsummaryrefslogtreecommitdiffstats
path: root/phpBB/install/convert
diff options
context:
space:
mode:
authorMarc Alexander <admin@m-a-styles.de>2017-01-07 16:16:24 +0100
committerMarc Alexander <admin@m-a-styles.de>2017-01-07 16:16:24 +0100
commit830a384988587c817d9426fade09d6dd227def5d (patch)
treef0fe8432b9970e2602b167b83c3d702c8d3da508 /phpBB/install/convert
parent9bbd034a4e818fbfef657e04c2a87c889af640af (diff)
downloadforums-830a384988587c817d9426fade09d6dd227def5d.tar
forums-830a384988587c817d9426fade09d6dd227def5d.tar.gz
forums-830a384988587c817d9426fade09d6dd227def5d.tar.bz2
forums-830a384988587c817d9426fade09d6dd227def5d.tar.xz
forums-830a384988587c817d9426fade09d6dd227def5d.zip
[prep-release-3.2.0] Fix links to convertor
Diffstat (limited to 'phpBB/install/convert')
-rw-r--r--phpBB/install/convert/controller/convertor.php14
1 files changed, 7 insertions, 7 deletions
diff --git a/phpBB/install/convert/controller/convertor.php b/phpBB/install/convert/controller/convertor.php
index 9a46117fe6..7b2a00d7b9 100644
--- a/phpBB/install/convert/controller/convertor.php
+++ b/phpBB/install/convert/controller/convertor.php
@@ -253,11 +253,11 @@ class convertor
/**
* Obtain convertor settings
*
* @param string $convertor Name of the convertor
*
* @return \Symfony\Component\HttpFoundation\Response|StreamedResponse
*/
- public function settings($convertor)
+ public function settings($converter)
{
$this->setup_navigation('settings');
@@ -265,7 +265,7 @@ class convertor
require_once ($this->phpbb_root_path . 'includes/functions_convert.' . $this->php_ext);
// Include convertor if available
- $convertor_file_path = $this->phpbb_root_path . 'install/convertors/convert_' . $convertor . '.' . $this->php_ext;
+ $convertor_file_path = $this->phpbb_root_path . 'install/convertors/convert_' . $converter . '.' . $this->php_ext;
if (!file_exists($convertor_file_path))
{
if ($this->request->is_ajax())
@@ -313,8 +313,8 @@ class convertor
// It must be an AJAX request at this point
$response = new StreamedResponse();
$ref = $this;
- $response->setCallback(function() use ($ref, $convertor) {
- $ref->proccess_settings_form($convertor);
+ $response->setCallback(function() use ($ref, $converter) {
+ $ref->proccess_settings_form($converter);
});
$response->headers->set('X-Accel-Buffering', 'no');
@@ -324,7 +324,7 @@ class convertor
{
$this->template->assign_vars(array(
'U_ACTION' => $this->controller_helper->route('phpbb_convert_settings', array(
- 'convertor' => $convertor,
+ 'converter' => $converter,
))
));
@@ -760,7 +760,7 @@ class convertor
'SOFTWARE' => $convertors[$index]['forum_name'],
'VERSION' => $convertors[$index]['version'],
- 'U_CONVERT' => $this->controller_helper->route('phpbb_convert_settings', array('convertor' => $convertors[$index]['tag'])),
+ 'U_CONVERT' => $this->controller_helper->route('phpbb_convert_settings', array('converter' => $convertors[$index]['tag'])),
));
}
@@ -253,11 +253,11 @@ class convertor
* Obtain convertor settings
*
- * @param string $convertor Name of the convertor
+ * @param string $converter Name of the convertor
*
* @return \Symfony\Component\HttpFoundation\Response|StreamedResponse